pub fn shared_sidecar(
sidecar: FakeSidecar,
) -> (Arc<FakeSidecar>, Arc<dyn Dispatcher>)Expand description
Wraps a FakeSidecar so the same handle can be given to Ports and
still be asked how many calls it saw.
pub fn shared_sidecar(
sidecar: FakeSidecar,
) -> (Arc<FakeSidecar>, Arc<dyn Dispatcher>)Wraps a FakeSidecar so the same handle can be given to Ports and
still be asked how many calls it saw.